pub struct GetLastPricesRequest {
pub figi: Vec<String>,
pub instrument_id: Vec<String>,
pub last_price_type: i32,
pub instrument_status: Option<i32>,
}Expand description
Запрос получения цен последних сделок.
Fields
figi: Vec<String>👎Deprecated
Deprecated FIGI-идентификатор инструмента. Используйте instrument_id.
instrument_id: Vec<String>Массив идентификаторов инструмента. Принимает значения figi или instrument_uid.
last_price_type: i32Тип запрашиваемой последней цены.
instrument_status: Option<i32>Статус запрашиваемых инструментов. Возможные значения.
Implementations
Sourceimpl GetLastPricesRequest
impl GetLastPricesRequest
Sourcepub fn last_price_type(&self) -> LastPriceType
pub fn last_price_type(&self) -> LastPriceType
Returns the enum value of last_price_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_last_price_type(&mut self, value: LastPriceType)
pub fn set_last_price_type(&mut self, value: LastPriceType)
Sets last_price_type to the provided enum value.
Sourcepub fn instrument_status(&self) -> InstrumentStatus
pub fn instrument_status(&self) -> InstrumentStatus
Returns the enum value of instrument_status, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_instrument_status(&mut self, value: InstrumentStatus)
pub fn set_instrument_status(&mut self, value: InstrumentStatus)
Sets instrument_status to the provided enum value.