pub struct RiskRatesResponse {
pub instrument_risk_rates: Vec<RiskRateResult>,
}Fields
instrument_risk_rates: Vec<RiskRateResult>Trait Implementations
Sourceimpl Clone for RiskRatesResponse
impl Clone for RiskRatesResponse
Sourcefn clone(&self) -> RiskRatesResponse
fn clone(&self) -> RiskRatesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RiskRatesResponse
impl Debug for RiskRatesResponse
Sourceimpl Default for RiskRatesResponse
impl Default for RiskRatesResponse
Sourceimpl Message for RiskRatesResponse
impl Message for RiskRatesResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl OwnedSender<RiskRatesRequest, RiskRatesResponse> for Api
impl OwnedSender<RiskRatesRequest, RiskRatesResponse> for Api
Sourcefn send_and_back(
self,
req: RiskRatesRequest,
) -> impl Future<Output = (Self, Result<RiskRatesResponse, Status>)>
fn send_and_back( self, req: RiskRatesRequest, ) -> impl Future<Output = (Self, Result<RiskRatesResponse, Status>)>
takes ownership, execute request and return self back after execution. Need for reusing of channels
Sourcefn send(
&self,
req: RiskRatesRequest,
) -> impl Future<Output = Result<RiskRatesResponse, Status>>
fn send( &self, req: RiskRatesRequest, ) -> impl Future<Output = Result<RiskRatesResponse, Status>>
just execute request, using &self. In most implementatinos it clones self
Sourceimpl OwnedSender<RiskRatesRequest, RiskRatesResponse> for Sandbox
impl OwnedSender<RiskRatesRequest, RiskRatesResponse> for Sandbox
Sourcefn send_and_back(
self,
req: RiskRatesRequest,
) -> impl Future<Output = (Self, Result<RiskRatesResponse, Status>)>
fn send_and_back( self, req: RiskRatesRequest, ) -> impl Future<Output = (Self, Result<RiskRatesResponse, Status>)>
takes ownership, execute request and return self back after execution. Need for reusing of channels
Sourcefn send(
&self,
req: RiskRatesRequest,
) -> impl Future<Output = Result<RiskRatesResponse, Status>>
fn send( &self, req: RiskRatesRequest, ) -> impl Future<Output = Result<RiskRatesResponse, Status>>
just execute request, using &self. In most implementatinos it clones self
Sourceimpl PartialEq for RiskRatesResponse
impl PartialEq for RiskRatesResponse
impl StructuralPartialEq for RiskRatesResponse